@@ -7,6 +7,7 @@
 
 var Path      = require('path'),
     stream    = require('stream'),
+    fs        = require('fs'),
     _         = require('lodash'),
     multipipe = require('multipipe'),
     csv       = require('fast-csv'),
@@ -145,12 +146,21 @@ module.exports = function(instruction) {
   var analysisConfig = ANALYSIS_CONFIG[instruction];
   var vcsType = appConfig.get('versionControlSystem');
 
+  var emptyStream = function() {
+    return _.tap(new stream.PassThrough(), function(s) { s.end(); });
+  };
+
   this.isSupported = _.memoize(function() { return _.includes(analysisConfig.supportedVcsTypes, vcsType); });
 
   this.fileAnalysisStream = function(inputFile, options) {
     if (!this.isSupported()) {
       logger.warn('CodeMaat ' + instruction + ' analysis not supported on ' + vcsType + ' repository');
-      return _.tap(new stream.PassThrough(), function(s) { s.end(); });
+      return emptyStream();
+    }
+
+    if (fs.statSync(inputFile).size === 0) {
+      logger.warn('Empty log file ' + inputFile);
+      return emptyStream();
     }
 
     var additionalOptions = _.extend({}, options, appConfig.get('codeMaat.options'));
