@@ -1,11 +1,18 @@
-var _    = require('lodash'),
-    fs   = require('fs'),
-    Path = require('path'),
-    glob = require('glob');
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
+var _     = require('lodash'),
+    Path  = require('path'),
+    glob  = require('glob'),
+    utils = require('../utils');
 
 module.exports = {
   makeGlob: function(path) {
-    if (!glob.hasMagic(path) && fs.existsSync(path) && fs.statSync(path).isDirectory()) {
+    if (!glob.hasMagic(path) && utils.fileSystem.isDirectory(path)) {
       return Path.join(path, '**/*');
     } else {
       return path;
@@ -14,7 +21,7 @@ module.exports = {
   expand: function(originalPaths, expander) {
     return _.reduce(originalPaths, function(array, path) {
       var expandedPaths = _.filter(expander(path), function(p) {
-        return fs.existsSync(p) && fs.statSync(p).isFile();
+        return utils.fileSystem.isFile(p);
       });
       return array.concat(expandedPaths);
     }, []);
