@@ -6,7 +6,7 @@
  */
 
 var _        = require('lodash'),
-    Q        = require('q'),
+    Bluebird = require('bluebird'),
     isStream = require('is-stream'),
     logger   = require('../log').Logger,
     utils    = require('../utils');
@@ -21,36 +21,30 @@ module.exports = function(jobRunner, opts) {
       }
       return utils.stream.streamToPromise(task);
     } else if (_.isFunction(task)) {
-      return Q.Promise(function(resolve) { return resolve(task()); });
+      return Bluebird.attempt(task);
     } else {
-      return Q(task);
+      return Bluebird.resolve(task);
     }
   };
 
-  var createJob = function(taskFn, deferred) {
-    try {
-      return processTask(taskFn())
-        .then(deferred.resolve.bind(deferred))
-        .catch(function(error) {
-          logger.warn(error);
-          deferred.reject(error);
-        });
-    } catch(error) {
-      logger.warn(error);
-      deferred.reject(error);
-    }
+  var createJob = function(taskFn, resolve, reject) {
+    return Bluebird.attempt(taskFn)
+      .then(processTask)
+      .then(resolve)
+      .catch(function(error) {
+        logger.warn(error);
+        reject(error);
+      });
   };
 
   this.processAll = function(taskFactoryList) {
-    var jobsPromises = [];
-
-    _.each(taskFactoryList, function(taskFn) {
-      var deferred = Q.defer();
-      jobsPromises.push(deferred.promise);
-      jobRunner.addJob(function() {
-        return createJob(taskFn, deferred);
-      });
+    var jobsPromises = _.map(taskFactoryList, function(taskFn) {
+      return new Bluebird(function(resolve, reject) {
+        jobRunner.addJob(function() {
+          return createJob(taskFn, resolve, reject);
+        });
+      }).reflect();
     });
-    return Q.allSettled(jobsPromises);
+    return Bluebird.all(jobsPromises);
   };
 };
