@@ -7,7 +7,7 @@
 
 var _        = require('lodash'),
     isStream = require('is-stream'),
-    Q        = require('q'),
+    Bluebird = require('bluebird'),
     utils    = require('../utils');
 
 var ReportComposer = function(initialDataSource) {
@@ -15,13 +15,13 @@ var ReportComposer = function(initialDataSource) {
 
   var processDataSource = function(source) {
     if (_.isArray(source)) {
-      return Q(source);
+      return Bluebird.resolve(source);
     } else if (isStream.readable(source)) {
       return utils.stream.objectStreamToArray(source);
     } else if (utils.fileSystem.isFile(source)) {
       return utils.json.fileToObject(source);
     } else {
-      return Q.reject(new Error('Invalid report source data: ' + source));
+      return Bluebird.reject(new Error('Invalid report source data: ' + source));
     }
   };
 
@@ -49,7 +49,7 @@ var ReportComposer = function(initialDataSource) {
 
   this.buildReport = function() {
     return processDataSource(initialDataSource).then(function(reportData) {
-      return Q.all(mergeAllReports(reportData)).then(function() {
+      return Bluebird.all(mergeAllReports(reportData)).then(function() {
         return reportData;
       });
     });
