@@ -7,7 +7,7 @@
 
 var _         = require('lodash'),
     filter    = require('through2-filter'),
-    Q         = require('q'),
+    Bluebird  = require('bluebird'),
     pp        = require('../parallel_processing'),
     logger    = require('../log').Logger,
     utils     = require('../utils'),
@@ -26,7 +26,7 @@ module.exports = function(taskDef, context, helpers) {
     }
     var vcsType = appConfig.get('versionControlSystem');
     logger.info('Codemaat: ' + reportType + ' analysis not avalable for ' + vcsType + '. Skipping...');
-    return Q.resolve();
+    return Bluebird.resolve();
   };
 
   var taskInfo = { parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }] };
