@@ -10,6 +10,7 @@ var fs        = require('fs'),
     filter    = require('through2-filter'),
     map       = require('through2-map'),
     reduce    = require('through2-reduce'),
+    Bluebird  = require('bluebird'),
     pp        = require('../parallel_processing'),
     reporting = require('../reporting'),
     wordCount = require('../analysers/word_count'),
@@ -49,7 +50,7 @@ module.exports = function(taskDef, context, helpers) {
     },
     ['effort-report'], function(publisher) {
       return utils.json.fileToObject(helpers.files.effort()).then(function(data) {
-        _.each([
+        var allDatafiles = _.map([
           { type: 'individual-effort', aggregateFn: 'aggregateIndividualEffortOwnership', propertyName: 'authors' },
           { type: 'team-effort', aggregateFn: 'aggregateTeamEffortOwnership', propertyName: 'teams' }
         ], function(report) {
@@ -57,9 +58,10 @@ module.exports = function(taskDef, context, helpers) {
           if (revisionsData) {
             publisher.enableDiagram(report.type);
             var tree = helpers.graphData.tree(revisionsData, 'path', report.propertyName);
-            utils.json.objectToFile(publisher.addReportFileForType(report.type), tree);
+            return utils.json.objectToFile(publisher.addReportFileForType(report.type), tree);
           }
         });
+        return Bluebird.all(allDatafiles);
       });
   });
 
