@@ -1,8 +1,15 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var _ = require('lodash');
 
 module.exports = {
   arrayToFnFactory: function(array, handler) {
-    return array.map(function(item) {
+    return _.map(array, function(item) {
       return _.wrap(item, handler);
     });
   },
