@@ -5,9 +5,9 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var fs = require('fs'),
-    _  = require('lodash'),
-    Q  = require('q');
+var fs       = require('fs'),
+    _        = require('lodash'),
+    Bluebird = require('bluebird');
 
 var queryEntity = function(queryFn, path) {
   return fs.existsSync(path) && fs.statSync(path)[queryFn]();
@@ -16,7 +16,5 @@ var queryEntity = function(queryFn, path) {
 module.exports = {
   isFile:      _.wrap('isFile', queryEntity),
   isDirectory: _.wrap('isDirectory', queryEntity),
-  writeToFile: function(filepath, content) {
-    return Q.nfcall(fs.writeFile, filepath, content);
-  }
+  writeToFile: Bluebird.promisify(fs.writeFile)
 };
