@@ -6,6 +6,6 @@
  */
 
 module.exports = {
-  Adapter:             require('./git_adapter'),
-  LogStreamTransfomer: require('./gitlog_stream_transformer')
+  Adapter:              require('./git_adapter'),
+  LogStreamTransformer: require('./gitlog_stream_transformer')
 };
