@@ -10,7 +10,7 @@
     map: {
       lodash:   '/lib/lodash/lodash.js',
       knockout: '/lib/knockout/build/output/knockout-latest.js',
-      q:        '/lib/q/q.js',
+      bluebird: '/lib/bluebird/js/browser/bluebird.min.js',
       mustache: '/lib/mustache/mustache.min.js',
       d3:       '/lib/d3/build/d3.min.js',
       d3Cloud:  '/lib/d3-cloud/build/d3.layout.cloud.js',
