@@ -5,8 +5,8 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var _ = require('lodash'),
-    Q = require('q');
+var _        = require('lodash'),
+    Bluebird = require('bluebird');
 
 module.exports = function(graphModels) {
   this.selectGraph = function(graphModel) {
@@ -15,7 +15,9 @@ module.exports = function(graphModels) {
     });
   };
 
-  Q.allSettled(_.invokeMap(graphModels, 'initialize')).then(function() {
-    graphModels[0].isSelected(true);
-  });
+  Bluebird.all(_.map(_.invokeMap(graphModels, 'initialize'), _.method('reflect')))
+    .then(function(promises) {
+      var index = _.findIndex(promises, _.method('isFulfilled'));
+      graphModels[index].isSelected(true);
+    });
 };
