@@ -5,9 +5,9 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var d3 = require('d3'),
-    Q  = require('q'),
-    _  = require('lodash');
+var d3       = require('d3'),
+    Bluebird = require('bluebird'),
+    _        = require('lodash');
 
 module.exports = function(options) {
   var packLayout = d3.pack()
@@ -20,7 +20,7 @@ module.exports = function(options) {
     });
   };
 
-  this.toSeries = function(data) {
+  this.toSeries = Bluebird.method(function(data) {
     normaliseData(data);
 
     var rootNode = d3.hierarchy(data);
@@ -29,6 +29,6 @@ module.exports = function(options) {
     });
     packLayout(rootNode);
 
-    return Q(rootNode.descendants());
-  };
+    return rootNode.descendants();
+  });
 };
