@@ -5,8 +5,8 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var d3 = require('d3'),
-    Q  = require('q');
+var d3       = require('d3'),
+    Bluebird = require('bluebird');
 
 module.exports = function(options) {
   var treemap = d3.treemap()
@@ -14,12 +14,12 @@ module.exports = function(options) {
     .round(false);
 
 
-  this.toSeries = function(data) {
+  this.toSeries = Bluebird.method(function(data) {
     var rootNode = d3.hierarchy(data).sum(function(node) {
       return node[options.valueProperty];
     });
     treemap(rootNode);
 
-    return Q(rootNode.descendants());
-  };
+    return rootNode.descendants();
+  });
 };
