@@ -5,9 +5,9 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var _  = require('lodash'),
-    Q  = require('q'),
-    ko = require('knockout');
+var _        = require('lodash'),
+    Bluebird = require('bluebird'),
+    ko       = require('knockout');
 
 var asyncLoader = require('../utils/async_loader.js');
 
@@ -25,7 +25,7 @@ module.exports = function() {
   };
 
   this.loadAllTemplates = function() {
-    return Q.all(_.map(templates, function(tmpl) {
+    return Bluebird.all(_.map(templates, function(tmpl) {
       return asyncLoader.loadTemplateIntoDocument(tmpl.properties.id, tmpl.properties.file);
     })).then(function() {
       self.templateIds(_.map(templates, 'properties.id'));
