@@ -40,14 +40,12 @@ module.exports = function(manifest) {
           viewTemplates: ['elementInfo3TooltipTemplate'],
           diagram: {
             Model: Model,
-            layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: cfg.valueProperty }),
-            graphHandlers: [new ZoomHandler({ diameter: 950 })],
+            layoutAdapter: new LayoutAdapter({ diameter: 1000, valueProperty: cfg.valueProperty }),
+            graphHandlers: [new ZoomHandler({ diameter: 1000 })],
             configuration: {
               style: {
                 cssClass: 'circle-packing-diagram',
-                width: 960,
-                height: 960,
-                diameter: 950,
+                diameter: 1000,
                 nodeDepthColorRange: ['hsl(185,60%,99%)', 'hsl(187,40%,70%)'],
                 weightedNodeColor: '#990012'
               },
