@@ -41,14 +41,12 @@ module.exports = function(manifest) {
           viewTemplates: ['elementInfo3TooltipTemplate'],
           diagram: {
             Model: Model,
-            layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: 'totalLines' }),
-            graphHandlers: [new ZoomHandler({ diameter: 950 })],
+            layoutAdapter: new LayoutAdapter({ diameter: 1000, valueProperty: 'totalLines' }),
+            graphHandlers: [new ZoomHandler({ diameter: 1000 })],
             configuration: {
               style: {
                 cssClass: 'circle-packing-diagram',
-                width: 960,
-                height: 960,
-                diameter: 950,
+                diameter: 1000,
                 nodeDepthColorRange: ['hsl(0,0%,100%)', 'hsl(0,0%,80%)']
               },
               colorScaleFactory: function(series) {
